@@ -2,24 +2,24 @@
 #######################################################################
 """Article class for the Zope 3 based ng.content.article package
 
-$Id: article.py 51881 2008-10-20 19:05:41Z cray $
+$Id: article.py 51946 2008-10-23 19:57:39Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 51881 $"
+__version__ = "$Revision: 51946 $"
  
 from zope.interface import implements
 
 from zope.app.container.ordered import OrderedContainer
 from ks.smartimage.smartimage import SmartImage
-from ng.content.article.interfaces import IDocShort,IDocFormatSwitcher
+from ng.content.article.interfaces import IDocShort,IDocFormatSwitcher,IArticleDesignSwitcher
 from interfaces import IArticleContainerOrdered,IArticleContained,IArticle
 import datetime
 import pytz 
 
 class ArticleBase(OrderedContainer):
     __doc__ = IArticle.__doc__
-    implements(IDocShort,IDocFormatSwitcher,IArticleContainerOrdered,IArticleContained)
+    implements(IDocShort,IDocFormatSwitcher,IArticleDesignSwitcher,IArticleContainerOrdered,IArticleContained)
 
     def __init__(self,*kv,**kw) :
         super(ArticleBase,self).__init__(*kv,**kw)
