@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based ng.content.article package
 
-$Id: interfaces.py 51881 2008-10-20 19:05:41Z cray $
+$Id: interfaces.py 51946 2008-10-23 19:57:39Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 51881 $"
+__version__ = "$Revision: 51946 $"
  
 from zope.interface import Interface,invariant,Invalid
 from zope.schema import Text, TextLine, Field, Bool, URI, Datetime, Object
@@ -16,6 +16,8 @@ from zope.app.container.constraints import ContainerTypesConstraint
 from ks.page.idocumentlogo.interfaces import IDocumentLogo
 from zope.app.container.interfaces import IReadContainer
 from ng.schema.regexp.regexpfield import Regexp
+from ng.schema.interfaceswitcher.interfacechoicefield import InterfaceChoice
+
 import datetime
 import pytz
 from ng.schema.interfaceswitcher.interfacechoicefield import InterfaceChoice
@@ -24,6 +26,11 @@ from ng.lib.dynamicdefault import DynamicDefault
 class IDocFormatSwitcher(Interface) :
     """ Format of contents document """
 
+class IArticleDesignSwitcher(Interface) :
+    iarticledesignswitcher = InterfaceChoice(title=u"Article Design",required=False)
+                                    
+IArticleDesignSwitcher['iarticledesignswitcher'].iface = IArticleDesignSwitcher
+
 class IDocTitle(Interface) :
     """ Attributes of article class """
     title = Regexp(title = u'Title',
@@ -36,7 +43,7 @@ class IDocTitle(Interface) :
             ),
         rewrite = (
             (u"^\s*(?P<name>\w+)\s*-\s*?(?P<number>[0-9]+)\s*$", u"%(name)s-%(number)s"),
-            (u"^\s*(?P<name>[^\s])\s*$", u"%(name)s"),
+            (u"^\s*(?P<name>[^\s]+)\s*$", u"%(name)s"),
             )
         )
 
@@ -76,7 +83,7 @@ class IDocProduct(Interface) :
 class ISContent(Interface) :
     """ ISContent """
     iscontent = Bool(title = u"Make content", default=False, required=True);
-    interface = InterfaceChoice(interface=IDocFormatSwitcher,  title=u"Interface")
+    idocformatswitcher = InterfaceChoice(interface=IDocFormatSwitcher,  title=u"Document Format")
 
 class IDocBody(ISContent) :
     """ Body of document class """
@@ -130,5 +137,11 @@ class IIconContainer(IContentContainer) :
 class IAbstractContainer(IContentContainer) :
     """ Container icons items """
 
-
-    
\ No newline at end of file
+class IArticleDesignSwitcher(Interface) :
+    """ Design article page """
+    
+class IArticleDesignSwitcher(Interface) :
+    iarticledesignswitcher = InterfaceChoice(title=u"Article Design")
+                                    
+IArticleDesignSwitcher['iarticledesignswitcher'].iface = IArticleDesignSwitcher
+                                            
\ No newline at end of file
